import pytest

from topobank.fixtures import api_rf, handle_usage_statistics, sync_analysis_functions  # noqa: F401
from topobank.manager.tests.utils import two_topos  # noqa: F401
from topobank.organizations.tests.utils import OrganizationFactory
from topobank.users.tests.factories import UserFactory


@pytest.mark.django_db
@pytest.fixture
def user_with_plugin(sync_analysis_functions):  # noqa: F811
    org_name = "Test Organization"
    org = OrganizationFactory(name=org_name, plugins_available="topobank_statistics")
    user = UserFactory()
    user.groups.add(org.group)
    return user



import importlib.metadata

from topobank.plugins import PluginConfig

try:
    __version__ = importlib.metadata.version('topobank-statistics')
except importlib.metadata.PackageNotFoundError:
    __version__ = '0.0.0'


class StatisticsPluginConfig(PluginConfig):
    default = True
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'topobank_statistics'
    verbose_name = "Statistical Analysis"

    class TopobankPluginMeta:
        name = "Statistical Analysis"
        version = __version__
        description = """
        Provides the following statistical analysis functions:
        - Height/Curvature/Slope Distribution
        - Autocorrelation
        - Power Spectrum
        - Roughness Parameters
        - Scale-dependent slope/curvature
        - Variable bandwidth
        """
        logo = "topobank_statistics/static/images/ce_logo.svg"
        restricted = False  # Accessible for all users, without permissions

    def ready(self):
        # make sure the functions are registered now
        import topobank_statistics.functions  # noqa: F401
        import topobank_statistics.views  # noqa: F401
        import topobank_statistics.downloads  # noqa: F401



from django.urls import reverse


def test_api():
    """Test API routes"""
    assert reverse('topobank_statistics:card-roughness-parameters',
                   kwargs=dict(function_id=123)) == '/plugins/statistics/card/roughness-parameters/123'



"""
Making urls from topobank available for tests.
"""

from django.urls import include, path
from django.conf import settings
from django.conf.urls.static import static

urlpatterns = [
    path(
        "manager/",
        include("topobank.manager.urls", namespace="manager"),
    ),
    path(
        "users/",
        include("topobank.users.urls", namespace="users"),
    ),
    path(
        "analysis/",
        include("topobank.analysis.urls", namespace="analysis"),
    ),
]

urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
